@@ -19,13 +19,13 @@
     </message>
     <message>
         <location filename="settingsdialog.ui" line="35"/>
-        <source>Height</source>
-        <translation>Höhe</translation>
+        <source>Height (px)</source>
+        <translation>Höhe (px)</translation>
     </message>
     <message>
         <location filename="settingsdialog.ui" line="55"/>
-        <source>Width</source>
-        <translation>Breite</translation>
+        <source>Width (px)</source>
+        <translation>Breite (px)</translation>
     </message>
     <message>
         <location filename="settingsdialog.ui" line="75"/>
@@ -39,8 +39,8 @@
     </message>
     <message>
         <location filename="settingsdialog.ui" line="92"/>
-        <source>Opacity</source>
-        <translation>Durchsichtigkeit</translation>
+        <source>Opacity (%)</source>
+        <translation>Undurchsichtigkeit (%)</translation>
     </message>
     <message>
         <location filename="settingsdialog.ui" line="115"/>
