@@ -65,28 +65,6 @@ void SettingsDialog::showAbout()
     this->close();
 }
 
-void SettingsDialog::checkVersion() {
-    QSettings settings;
-    QString oldVersion = settings.value(PCW_SETTING_LASTVERSION).toString();
-    QString curVersion = QApplication::applicationVersion();
-    if(oldVersion != curVersion) {
-        settings.setValue(PCW_SETTING_LASTVERSION, curVersion);
-        QString tmpInfo;
-        if(oldVersion == PCW_SETTING_LASTVERSION_DEFAULT) {
-            //Show info for user that have installed the app for the first time.
-            tmpInfo.append(tr("Thank you for installing profile changer widget."));
-        } else {
-            //Show update info
-            tmpInfo.append(tr("Thank you for updating profile changer widget."));
-        }
-        tmpInfo.append("\n");
-        tmpInfo.append(tr("Feel free to support my work by testing the application in order to get it to Extras -repository."));
-        tmpInfo.append("\n");
-        tmpInfo.append(tr("Therefore you can use the \"Feedback\" button."));
-        this->showQuestion(tmpInfo);
-    }
-}
-
 void SettingsDialog::on_buttonAbout_clicked()
 {
     this->showAbout();
@@ -141,18 +119,3 @@ void SettingsDialog::showInformation(QString info)
     msg = QDBusConnection::sessionBus().call(msg);
 
 }
-
-void SettingsDialog::showQuestion(QString info)
-{
-    QDBusMessage msg = QDBusMessage::createMethodCall(
-        "org.freedesktop.Notifications", // --dest
-        "/org/freedesktop/Notifications", // destination object path
-        "org.freedesktop.Notifications", // message name (w/o method)
-        "SystemNoteDialog" // method
-    );
-    msg << info;
-    msg << 0;
-    msg << "Ok";
-    msg = QDBusConnection::sessionBus().call(msg);
-
-}
